import { Server } from "socket.io";
import {TSocket} from "../../../utilities/Types";
import TileTagRepository from "../../../repositories/TileTagRepository";

interface IPayload {
  tile: string;
}

/**
 * Handle game master tile tags update event
 * @param socket
 * @param io
 */
export default function (socket: TSocket, io: Server) {
  socket.on('gm:tile:tags', async (data: IPayload, callback: (response: string[]) => void) => {

    if (socket.character?.role !== 'gm') {
      return;
    }

    // update the tile tags
    try {
      const tileTag = await TileTagRepository.getTileTag(data.tile);
      callback(tileTag ? tileTag.tags as string[] : []);
    } catch (error) {
      console.log(error);
      callback([]);
    }
  });
}