import { Server } from "socket.io";
import {TSocket} from "../../../utilities/Types";
import TileTagRepository from "../../../repositories/TileTagRepository";

interface IPayload {
  tile: string;
  tags: string[];
}

/**
 * Handle game master tile tags update event
 * @param socket
 * @param io
 */
export default function (socket: TSocket, io: Server) {
  socket.on('gm:tile:tags:update', async (data: IPayload, callback: (response: boolean) => void) => {

    if (socket.character?.role !== 'gm') {
      return;
    }

    // update the tile tags
    try {
      await TileTagRepository.upsertTileTag(data.tile, data.tags);
      callback(true);
    } catch (error) {
      console.log(error);
      callback(false);
    }
  });
}